@@ -21,14 +21,12 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.aws_iam
+from ._jsii import *
+
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
 import aws_cdk.core
-import constructs
-
-from ._jsii import *
 
 
 @jsii.implements(aws_cdk.aws_logs.ILogSubscriptionDestination)
